==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/lex/kotlin/inputs/IntentFollowUpPromptPromptMessageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.lex.kotlin.inputs

import com.pulumi.aws.lex.inputs.IntentFollowUpPromptPromptMessageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property content The text of the message. Must be less than or equal to 1000 characters in length.
 * @property contentType The content type of the message string.
 * @property groupNumber Identifies the message group that the message belongs to. When a group
 * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
 */
public data class IntentFollowUpPromptPromptMessageArgs(
    public val content: Output<String>,
    public val contentType: Output<String>,
    public val groupNumber: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.lex.inputs.IntentFollowUpPromptPromptMessageArgs> {
    override fun toJava(): com.pulumi.aws.lex.inputs.IntentFollowUpPromptPromptMessageArgs =
        com.pulumi.aws.lex.inputs.IntentFollowUpPromptPromptMessageArgs.builder()
            .content(content.applyValue({ args0 -> args0 }))
            .contentType(contentType.applyValue({ args0 -> args0 }))
            .groupNumber(groupNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IntentFollowUpPromptPromptMessageArgs].
 */
@PulumiTagMarker
public class IntentFollowUpPromptPromptMessageArgsBuilder internal constructor() {
    private var content: Output<String>? = null

    private var contentType: Output<String>? = null

    private var groupNumber: Output<Int>? = null

    /**
     * @param value The text of the message. Must be less than or equal to 1000 characters in length.
     */
    @JvmName("tonnlutkajogrejr")
    public suspend fun content(`value`: Output<String>) {
        this.content = value
    }

    /**
     * @param value The content type of the message string.
     */
    @JvmName("fmdigebenpfuilea")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value Identifies the message group that the message belongs to. When a group
     * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
     */
    @JvmName("lkylieixvfslptop")
    public suspend fun groupNumber(`value`: Output<Int>) {
        this.groupNumber = value
    }

    /**
     * @param value The text of the message. Must be less than or equal to 1000 characters in length.
     */
    @JvmName("mymxiccybyujxnjr")
    public suspend fun content(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The content type of the message string.
     */
    @JvmName("kdtbnqbflchdmlse")
    public suspend fun contentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value Identifies the message group that the message belongs to. When a group
     * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
     */
    @JvmName("rbfijgqplghdwmws")
    public suspend fun groupNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupNumber = mapped
    }

    internal fun build(): IntentFollowUpPromptPromptMessageArgs =
        IntentFollowUpPromptPromptMessageArgs(
            content = content ?: throw PulumiNullFieldException("content"),
            contentType = contentType ?: throw PulumiNullFieldException("contentType"),
            groupNumber = groupNumber,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/lex/kotlin/inputs/IntentFollowUpPromptPromptMessageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.lex.kotlin.inputs

import com.pulumi.aws.lex.inputs.IntentFollowUpPromptPromptMessageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property content The text of the message. Must be less than or equal to 1000 characters in length.
 * @property contentType The content type of the message string.
 * @property groupNumber Identifies the message group that the message belongs to. When a group
 * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
 */
public data class IntentFollowUpPromptPromptMessageArgs(
    public val content: Output<String>,
    public val contentType: Output<String>,
    public val groupNumber: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.lex.inputs.IntentFollowUpPromptPromptMessageArgs> {
    override fun toJava(): com.pulumi.aws.lex.inputs.IntentFollowUpPromptPromptMessageArgs =
        com.pulumi.aws.lex.inputs.IntentFollowUpPromptPromptMessageArgs.builder()
            .content(content.applyValue({ args0 -> args0 }))
            .contentType(contentType.applyValue({ args0 -> args0 }))
            .groupNumber(groupNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IntentFollowUpPromptPromptMessageArgs].
 */
@PulumiTagMarker
public class IntentFollowUpPromptPromptMessageArgsBuilder internal constructor() {
    private var content: Output<String>? = null

    private var contentType: Output<String>? = null

    private var groupNumber: Output<Int>? = null

    /**
     * @param value The text of the message. Must be less than or equal to 1000 characters in length.
     */
    @JvmName("fnvbatpwqahobyjc")
    public suspend fun content(`value`: Output<String>) {
        this.content = value
    }

    /**
     * @param value The content type of the message string.
     */
    @JvmName("fmgxhkncxbcebdmh")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value Identifies the message group that the message belongs to. When a group
     * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
     */
    @JvmName("ewgasdhemjviqtqu")
    public suspend fun groupNumber(`value`: Output<Int>) {
        this.groupNumber = value
    }

    /**
     * @param value The text of the message. Must be less than or equal to 1000 characters in length.
     */
    @JvmName("pkydbwxvsbxvtmjy")
    public suspend fun content(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The content type of the message string.
     */
    @JvmName("ojylgfjnnaepxwyv")
    public suspend fun contentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value Identifies the message group that the message belongs to. When a group
     * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
     */
    @JvmName("vuyukleyvsypnqij")
    public suspend fun groupNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupNumber = mapped
    }

    internal fun build(): IntentFollowUpPromptPromptMessageArgs =
        IntentFollowUpPromptPromptMessageArgs(
            content = content ?: throw PulumiNullFieldException("content"),
            contentType = contentType ?: throw PulumiNullFieldException("contentType"),
            groupNumber = groupNumber,
        )
}
